@@ -32,30 +32,23 @@ class Regbot:
 
 
   @classmethod
-  def buySignalGenerator(cls,opening,closing,volume,alpha):
+  def buySignalGenerator(cls,opening,closing,volume):
     scalledInput = cls.prepareInput(opening,closing,volume)
-    return (cls.loadmodel().predict_proba(scalledInput)[0:,1] > alpha).astype("int32")[0]
+    return cls.loadmodel().predict(scalledInput)[0].round() #[0:,1] > alpha).astype("int32")[0]
     
+  '''
   @classmethod
-  def sellSignalGenerator(cls,opening,closing,volume,alpha):
+  def sellSignalGenerator(cls,opening,closing,volume):
     scalledInput = cls.prepareInput(opening,closing,volume)
-    return (cls.loadmodel().predict_proba(scalledInput)[0:,0] > alpha).astype("int32")[0]
+    return cls.loadmodel().predict(scalledInput).round() #[0:,0] > alpha).astype("int32")[0]
+  '''
 
 
-
-def signal(opening,closing,volume,alpha,sig):
-  if sig == 'buy':
-    try:
-      return Regbot.buySignalGenerator(opening,closing,volume,alpha)
-    except Exception as e:
-      print(e)
-  elif sig == 'sell':
-    try:
-      return Regbot.sellSignalGenerator(opening,closing,volume,alpha)
-    except Exception as e:
-      print(e)
-  else:
-    return f'{sig} is not a valid entry!'
+def signal(opening,closing,volume):
+  try:
+    return Regbot.buySignalGenerator(opening,closing,volume)
+  except Exception as e:
+    print(e)
 
 
 if __name__ == '__main__':
